/*

 ============================================================================
 The Apache Software License, Version 1.1
 ============================================================================

 Copyright (C) 1999-2003 The Apache Software Foundation. All rights reserved.

 Redistribution and use in source and binary forms, with or without modifica-
 tion, are permitted provided that the following conditions are met:

 1. Redistributions of  source code must  retain the above copyright  notice,
 this list of conditions and the following disclaimer.

 2. Redistributions in binary form must reproduce the above copyright notice,
 this list of conditions and the following disclaimer in the documentation
 and/or other materials provided with the distribution.

 3. The end-user documentation included with the redistribution, if any, must
 include  the following  acknowledgment:  "This product includes  software
 developed  by the  Apache Software Foundation  (http://www.apache.org/)."
 Alternately, this  acknowledgment may  appear in the software itself,  if
 and wherever such third-party acknowledgments normally appear.

 4. The names "Batik" and  "Apache Software Foundation" must  not  be
 used to  endorse or promote  products derived from  this software without
 prior written permission. For written permission, please contact
 apache@apache.org.

 5. Products  derived from this software may not  be called "Apache", nor may
 "Apache" appear  in their name,  without prior written permission  of the
 Apache Software Foundation.

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED WARRANTIES,
 INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 FITNESS  FOR A PARTICULAR  PURPOSE ARE  DISCLAIMED.  IN NO  EVENT SHALL  THE
 APACHE SOFTWARE  FOUNDATION  OR ITS CONTRIBUTORS  BE LIABLE FOR  ANY DIRECT,
 INDIRECT, INCIDENTAL, SPECIAL,  EXEMPLARY, OR CONSEQUENTIAL  DAMAGES (INCLU-
 DING, BUT NOT LIMITED TO, PROCUREMENT  OF SUBSTITUTE GOODS OR SERVICES; LOSS
 OF USE, DATA, OR  PROFITS; OR BUSINESS  INTERRUPTION)  HOWEVER CAUSED AND ON
 ANY  THEORY OF LIABILITY,  WHETHER  IN CONTRACT,  STRICT LIABILITY,  OR TORT
 (INCLUDING  NEGLIGENCE OR  OTHERWISE) ARISING IN  ANY WAY OUT OF THE  USE OF
 THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 This software  consists of voluntary contributions made  by many individuals
 on  behalf of the Apache Software  Foundation. For more  information on the
 Apache Software Foundation, please see <http://www.apache.org/>.

 */

package jp.cssj.sakae.sac.parser;

import org.w3c.css.sac.SACMediaList;

/**
 * This class implements the {@link SACMediaList}interface.
 * 
 * @author <a href="mailto:stephane@hillion.org">Stephane Hillion </a>
 * @version $Id: CSSSACMediaList.java,v 1.2 2007-05-06 04:24:08 miyabe Exp $
 */
public class CSSSACMediaList implements SACMediaList {

	/**
	 * The list.
	 */
	protected String[] list = new String[3];

	/**
	 * The list length.
	 */
	protected int length;

	/**
	 * <b>SAC </b>: Returns the length of this selector list
	 */
	public int getLength() {
		return length;
	}

	/**
	 * <b>SAC </b>: Returns the selector at the specified index, or
	 * <code>null</code> if this is not a valid index.
	 */
	public String item(int index) {
		if (index < 0 || index >= length) {
			return null;
		}
		return list[index];
	}

	/**
	 * Appends an item to the list.
	 */
	public void append(String item) {
		if (length == list.length) {
			String[] tmp = list;
			list = new String[list.length * 3 / 2];
			for (int i = 0; i < tmp.length; i++) {
				list[i] = tmp[i];
			}
		}
		list[length++] = item;
	}

	public String toString() {
		StringBuffer buff = new StringBuffer();
		if (this.length > 0) {
			buff.append(this.list[0]);
			for (int i = 1; i < this.length; ++i) {
				buff.append(", ");
				buff.append(this.list[i]);
			}
		}
		return buff.toString();
	}
}